package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltProjectMonthDetail;
import com.bonus.material.settlement.service.ISltProjectMonthDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 月结算费用详情Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "月结算费用详情接口")
@RestController
@RequestMapping("/slt_project_month_detail")
public class SltProjectMonthDetailController extends BaseController {
    @Autowired
    private ISltProjectMonthDetailService sltProjectMonthDetailService;

    /**
     * 查询月结算费用详情列表
     */
    @ApiOperation(value = "查询月结算费用详情列表")
    @RequiresPermissions("settlement:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(SltProjectMonthDetail sltProjectMonthDetail) {
        startPage();
        List<SltProjectMonthDetail> list = sltProjectMonthDetailService.selectSltProjectMonthDetailList(sltProjectMonthDetail);
        return getDataTable(list);
    }

    /**
     * 导出月结算费用详情列表
     */
    @ApiOperation(value = "导出月结算费用详情列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:detail:export")
    @SysLog(title = "月结算费用详情", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出月结算费用详情")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltProjectMonthDetail sltProjectMonthDetail) {
        List<SltProjectMonthDetail> list = sltProjectMonthDetailService.selectSltProjectMonthDetailList(sltProjectMonthDetail);
        ExcelUtil<SltProjectMonthDetail> util = new ExcelUtil<SltProjectMonthDetail>(SltProjectMonthDetail.class);
        util.exportExcel(response, list, "月结算费用详情数据");
    }

    /**
     * 获取月结算费用详情详细信息
     */
    @ApiOperation(value = "获取月结算费用详情详细信息")
    @RequiresPermissions("settlement:detail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltProjectMonthDetailService.selectSltProjectMonthDetailById(id));
    }

    /**
     * 新增月结算费用详情
     */
    @ApiOperation(value = "新增月结算费用详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:detail:add")
    @SysLog(title = "月结算费用详情", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增月结算费用详情")
    @PostMapping
    public AjaxResult add(@RequestBody SltProjectMonthDetail sltProjectMonthDetail) {
        try {
            return toAjax(sltProjectMonthDetailService.insertSltProjectMonthDetail(sltProjectMonthDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改月结算费用详情
     */
    @ApiOperation(value = "修改月结算费用详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:detail:edit")
    @SysLog(title = "月结算费用详情", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改月结算费用详情")
    @PutMapping
    public AjaxResult edit(@RequestBody SltProjectMonthDetail sltProjectMonthDetail) {
        try {
            return toAjax(sltProjectMonthDetailService.updateSltProjectMonthDetail(sltProjectMonthDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除月结算费用详情
     */
    @ApiOperation(value = "删除月结算费用详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:detail:remove")
    @SysLog(title = "月结算费用详情", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除月结算费用详情")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltProjectMonthDetailService.deleteSltProjectMonthDetailByIds(ids));
    }
}
